%=============================================================
%               Exemple de code pour le TPA04 : 
%   ACP applique  des variables climatiques lies  l'effet
%   de serre.
%   Cette procdure enchaine l'ACP "saisonnire" puis
%   "interannuelle". 
%   . Vous pouvez choisir, parmis les villes disponnibles
%   celle(s) que vous souhaitez traiter : voir la variable
%   vil2process dans le code.
%   . Vous pouvez galement choisir les axes  utiliser pour
%   les cercles de corrlations et les nuages des individus :
%   voir les variables cpa et cpb dans le code
%
clear all; close all; clc
%=============================================================
% 1) Climatologies mensuelles par ville des variables  
%    t2, tcc, lsp, cp, ssr et CO2.
xclimmens % nb: Ce script effectue ncessairement le chargement
%           des donnes, et fait aussi quelques initialisations.
%
%=============================================================
% Selection de la ou des villes  tudier :
%{'Reykjavik','Oslo','Paris','New York','Tunis','Alger','Beyrouth','Atlan','Dakar'};
%      1         2      3        4         5       6        7         8       9
vil2process = [1]; %[1, 6, 9]; <<< Choisir la (ou les) ville par son indice
%
for i=1:length(vil2process);
  %***********************************************************
  %***********************************************************
  % 2.1) CAS DE L'ETUDE "SAISONNIERE"
  %***********************************************************
  %***********************************************************
  % Some init
  individ = cellstr(num2str(clim_t2(:,2)));  % Labellisation des individus par leur mois
  k = vil2process(i); % kime ville (indice de la ville courante)
  %_______________________
  % Matrice des donnes pour la kime ville :
  % ----------------------
  % 1re col=anne, 2me col=mois => on prend la 2+kieme colonne
  Z = [clim_t2(:,2+k), clim_tcc(:,2+k), clim_lsp(:,2+k),  ...
       clim_cp(:,2+k), clim_ssr(:,2+k), clim_co2(:,3)];
  %
  [NbIndiv, NbVar] = size(Z);       % dimension (n,p)
  X = centred(Z, mean(Z), std(Z));  % Normalisation par Centrage et Rduction
  %_______________________
  % A C P (elle-meme) :
  % ----------------------
  if (exist('OCTAVE_VERSION'))
     [VEPU, CP, VAP] = ocp(X);
  else
     [VEPU, CP, VAP, TSQUARE] = princomp(X);
  end
  %_______________________
  % Pourcentage d'inertie et d'inertie cumule des valeurs propres :
  % ----------------------
  phinertie(VAP); % Pourcentage et histogramme de l'inertie des valeurs propres
  % habillage
  set(gcf,'color','w');
  h=title([lieux{k},': Pourcentage d''inertie des valeurs propres']);
  set(h,'fontsize',13,'fontweight','bold');
  set(gca,'fontsize',11,'fontweight','bold');  
  %_______________________
  % Choix des axes de plan principaux :
  % ----------------------
  cpa=1; cpb=2; %cpa=3; cpb=4; 
  %_______________________
  % Cercle de corrlations :
  % ----------------------
  corcer(X,CP,cpa,cpb,variables); 
  set(gcf,'color','w');                                    
  set(gca,'fontsize',10,'fontweight','bold');
  title(sprintf('%s: Cercle des corrlations des variables avec les axes principaux %i et %i',lieux{k},cpa,cpb));
  %_______________________
  % Nuage des individus sur le plan des axes principaux :
  % ----------------------
  % Qualit de reprsentation
  dist = (sum((CP').^2))';
  QLT = (CP.^2) ./ (dist*ones(1,size(CP,2)));
  %
  selim = 0.5; % Limite de selection des individus par rapport  leur QLT
  if (cpa>2 | cpb>2) selim=0.25; end % cas des axes > 2
  Iqlt = find(QLT(:,cpa)>selim | QLT(:,cpb)>selim); % Indices des individus qui ont une QLT > selim (sur l'un ou l'autre des axes du plan)
  %
  % Nuage des individus avec les mois en chelle de couleur :
  echcol = clim_t2(:,2); echcolname='mois'; % Echelle de couleur :les mois
  acpnuage(CP(Iqlt,:),cpa,cpb,echcol(Iqlt),individ(Iqlt),QLT(Iqlt,:),15); % fonction de reprsentation du nuage
  % habillage complementaire ou override
  set(gcf,'color','w');
  set(gca,'fontsize',11,'fontweight','bold');
  h=title(sprintf('%s: NI(%i>%.2f) sur le plan des axes principaux %i et %i  Ech.col : %s',lieux{k},length(Iqlt),selim,cpa,cpb,echcolname));
  set(h,'fontsize',11,'fontweight','bold');
  %
  % Nuage des individus avec les annes en chelle de couleur :
  echcol = clim_t2(:,1); echcolname='annes'; % Echelle de couleur : les annes
  acpnuage(CP(Iqlt,:),cpa,cpb,echcol(Iqlt),individ(Iqlt),QLT(Iqlt,:),15); 
  set(gcf,'color','w');
  set(gca,'fontsize',11,'fontweight','bold'); 
  h=title(sprintf('%s: NI(%i>%.2f) sur le plan des axes principaux %i et %i  Ech.col : %s',lieux{k},length(Iqlt),selim,cpa,cpb,echcolname));
  set(h,'fontsize',11,'fontweight','bold');
  %
  %***********************************************************
  %***********************************************************
  % 2.2) CAS DE L'ETUDE "INTERANNUELLE"
  %***********************************************************
  %***********************************************************
  % Some more Init :
  andeb = clim_t2(1,1);   % Annee de debut, ... 
  anfin = clim_t2(end,1); % ... et de fin.
  individ = cellstr(num2str([andeb:anfin]')); % Pour l'identification des individus
  %_______________________
  % Calcul des moyennes annuelles :
  % ----------------------
  Z = moyan([clim_t2(:,1), Z]);
  %
  [NbIndiv, NbVar] = size(Z);       % dimension (n,p)
  X = centred(Z, mean(Z), std(Z));  % Normalisation par Centrage et Rduction
  %_______________________
  % Affichage des variables normalises :
  % ----------------------
  figure; hold on; set(gcf,'color',[1 1 1]);
  if (exist('OCTAVE_VERSION'))
     Col = hsv(NbVar+1); % Choix, dfinition d'une map de couleur
  else
     Col = hsv(NbVar); % Choix, dfinition d'une map de couleur
  end
  for i=1:NbVar; 
      plot(X(:,i),'*-','color',Col(i,:),'linewidth',1.5);
  end
  axis tight; box on;
  % Labellisation de l'abscisse avec les annes
  Ilab = [1:NbIndiv]; Xlab = [andeb:anfin]; % Indice  labelliser
  set(gca,'XTick',Ilab, 'XTickLabel',Xlab,'fontsize',12,'fontweight','bold'); % on labellise
  % Habillage
  legend(variables);
  title([lieux{k}, ' : moyennes annuelles centres et rduites'],'fontsize',16); %,24);
  %_______________________
  % A C P (elle-meme) :
  % ----------------------
  if (exist('OCTAVE_VERSION'))
     [VEPU, CP, VAP] = ocp(X);
  else
     [VEPU, CP, VAP, TSQUARE] = princomp(X);
  end
  %_______________________
  % Pourcentage d'inertie et d'inertie cumulee des valeurs propres :
  % ----------------------
  phinertie(VAP); 
  set(gcf,'color',[1 1 1]);
  h=title([lieux{k},': Pourcentage d''inertie des valeurs propres']);
  set(h,'fontsize',13,'fontweight','bold');
  set(gca,'fontsize',11,'fontweight','bold');  
  %_______________________
  % Choix des axes du plan principal : on garde les memes
  % que ceux de l'analyse "saisonnire" 
  %_______________________
  % Cercle de corrlations
  % ----------------------
  corcer(X,CP,cpa,cpb,variables);
  set(gcf,'color','w');
  set(gca,'fontsize',10,'fontweight','bold');
  title(sprintf('%s: Cercle des corrlations des variables avec les axes principaux %i et %i',lieux{k},cpa,cpb));
  %_______________________
  % Qualit de reprsentation
  dist = (sum((CP').^2))';
  QLT = (CP.^2) ./ (dist*ones(1,size(CP,2)));
  %
  % Nuage des individus sur le plan principal
  echcol = [andeb:anfin]'; echcolname='annes'; %  L'anne en chelle de couleur :
  acpnuage(CP,cpa,cpb,echcol,individ,QLT,15);
  set(gcf,'color',[1 1 1]);
  set(gca,'fontsize',10,'fontweight','bold');
  title(sprintf('%s: NI sur le plan des axes principaux %i et %i  Ech.col : %s',lieux{k},cpa,cpb,echcolname));
  %
  %***********************************************************
%
end % du for i=1:length(vil2process);
%
%=============================================================
%
